@@ -124,13 +124,13 @@ class GluePathsModel(BasePathsModel):
 
 
 class SnowflakePathsModel(BasePathsModel):
-    databases: Optional[str]
+    databases: str
     schemas: Optional[str]
     tables: Optional[str]
     views: Optional[str]
     tables_columns: Optional[str] = Field(alias="columns")
     views_columns: Optional[str] = Field(alias="columns")
-    owners: Optional[str]
+    pipes: Optional[str]
 
     class Config:
         dependencies_map = {
@@ -138,19 +138,9 @@ class SnowflakePathsModel(BasePathsModel):
             "schemas": ("databases", "schemas"),
             "tables": ("databases", "schemas", "tables"),
             "views": ("databases", "schemas", "views"),
-            "tables_columns": (
-                "databases",
-                "schemas",
-                "tables",
-                "tables_columns",
-            ),
-            "views_columns": (
-                "databases",
-                "schemas",
-                "views",
-                "views_columns",
-            ),
-            "owners": ("databases", "owners"),
+            "tables_columns": ("databases", "schemas", "tables", "tables_columns"),
+            "views_columns": ("databases", "schemas", "views", "views_columns"),
+            "pipes": ("pipes",),
         }
         data_source_path = "databases"
 
@@ -435,13 +425,18 @@ class S3PathsModel(BasePathsModel):
 class CassandraPathsModel(BasePathsModel):
     keyspaces: str
     tables: Optional[str]
+    views: Optional[str]
     columns: Optional[str]
+    tables_columns: Optional[str] = Field(alias="columns")
+    views_columns: Optional[str] = Field(alias="columns")
 
     class Config:
         dependencies_map = {
             "keyspaces": ("keyspaces",),
             "tables": ("keyspaces", "tables"),
-            "columns": ("keyspaces", "tables", "columns"),
+            "views": ("keyspaces", "views"),
+            "tables_columns": ("keyspaces", "tables", "tables_columns"),
+            "views_columns": ("keyspaces", "views", "views_columns"),
         }
         data_source_path = "keyspaces"
 
@@ -640,3 +635,34 @@ class GreatExpectationsPathsModel(BasePathsModel):
             "types": ("suites", "types"),
             "runs": ("suites", "types", "runs"),
         }
+
+
+class DatabricksLakehousePathModel(BasePathsModel):
+    databases: Optional[str]
+    tables: Optional[str]
+    columns: Optional[str]
+
+    class Config:
+        dependencies_map = {
+            "databases": ("databases",),
+            "tables": ("databases", "tables"),
+            "columns": ("databases", "tables", "columns"),
+        }
+
+
+class SingleStorePathsModel(BasePathsModel):
+    databases: str
+    tables: Optional[str]
+    views: Optional[str]
+    tables_columns: Optional[str] = Field(alias="columns")
+    views_columns: Optional[str] = Field(alias="columns")
+
+    class Config:
+        dependencies_map = {
+            "databases": ("databases",),
+            "tables": ("databases", "tables"),
+            "views": ("databases", "views"),
+            "tables_columns": ("databases", "tables", "tables_columns"),
+            "views_columns": ("databases", "views", "views_columns"),
+        }
+        data_source_path = "databases"
